#ifndef AK_HMAC_IMPL_HPP
#define AK_HMAC_IMPL_HPP

#include "SecretKey.hpp" 
#include "Error.hpp" 

namespace Akenti {

/**
  * @see SecretKey
  * @see Hmac 
  *
  * @author Abdelilah Essiari
  */
class HmacImpl {

public:

  /**
    * Destroys this engine.
    */
  virtual ~HmacImpl() {
  }

  /**
    */
  void init(const SecretKey& key_arg) {
    this->key = key_arg;
    initialized = true;
    resetEngine();
  }

  /**
    */
  virtual void resetEngine() {
  } 

  /**
    */
  virtual int getSize() const {
    return 0;
  } 

  /**
    */
  void update(const string& data) {
    update(data, 0, data.length());
  }

  /**
    */
  void update(const string& data, int offset, int len) {
    if (data.length() - offset < len) {
      throw Error("HmacImpl:update:input buffer too short");
    } else if (!initialized) {
      throw Error("HmacImpl:update:illegal operation");
    }
    
    doUpdate(data, offset, len);
  }

  /**
    */
  string digest() {
    string ret = doDigest();
    
    initialized = false;
    return ret;
  } 
 
  /**
    */
  bool verify(const string& tag) {
    return digest() == tag;
  }
 
protected:

  friend class Hmac;

  /**
    */
  HmacImpl(const string& alg) : alg(alg), initialized(false) {
  }

  /**
    */
  virtual void doUpdate(const string& data, int offset, int len) {
  }

  /**
    */
  virtual string doDigest() {
    return "";
  }
  
  SecretKey key;

  string alg;

  bool initialized;

};

}

#endif
