#ifndef AKENTI_HTTP_BASE_HPP
#define AKENTI_HTTP_BASE_HPP

#include <string>
#include <sstream>
#include "InputStream.hpp"
#include "OutputStream.hpp"
#include "HttpConstants.hpp"

using std::string;
using std::ostringstream;

namespace Akenti {

/**
  * A convenience class that implements behavior common to <i>HttpRequest</i> 
  * and <i>HttpResponse</i>.
  *
  * @version 1.1 12/26/02
  * @author Abdelilah Essiari 
  */	

class HttpBase : public HttpConstants {

protected:

  /**
    */
  HttpBase();

  /**
    */
  ~HttpBase();

public:

  /**
    */
  void setProtocol(const string& protocol);

  /**
    */
  const string& getProtocol() const;

  /**
    */
  void setContentType(const string& contentType);
  
  /**
    */
  const string& getContentType() const;

  /**
    * Server side call to get the length of the body.
    */
  int getContentLength() const;

  /**
    * Server side call to read the body of the request.
    */
  InputStream getInputStream() const;

  /**
    * Client side call to write the body.
    */
  OutputStream getOutputStream();

protected:

  void readLine(string& line, InputStream&) const ;

  InputStream is;

  OutputStream os;

  ostringstream* obuff;

  string protocol;

  string contentType;
  
  int contentLength;

};

} // end of name space

#endif
