#ifndef UTIL_HPP 
#define UTIL_HPP

#include <string>

using std::string;

namespace Akenti {

class DistinguishedName;

/**
  * This class provides a collection of static methods.
  * 
  * @see DistinguishedName 
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

struct Util {
  
public:

  /**
    * Provides a comparison of each value, attribute pairs
    * between two distinguished names. The comparison of
    * the attributes is not case sensitive.  
    *
    */ 
  static bool 
  compare(const DistinguishedName& dn1, const DistinguishedName& dn2);

  /**
    * Returns a string that contains the value and pair used 
    * for hashing. Only the attributes below are used. 
    *
    * "CN", "C", "O", "OU", "DC", "cn", "c", "o", "ou", "dc".
    */
  static string 
  getHashDN(const DistinguishedName& dn); 

  /**
    * Returns a file name used to locate certificates. 
    *
    * @param digest the string used to create the digest
    */
  static string 
  createFileName(const string& digest);

  /**
    * Returns hostname#id#date
    */
  static string
  createUniqueID(const string& id);

  /**
    * Provides indentation and wrapping for the string.
    * Processes two forms of string.  One with a ':' in 
    * it, and one without. If a string has a colon and 
    * its length is greater than 70 the remaining string
    * will wrap after the colon in the string, otherwise 
    * the string will wrap after the indentation.   
    *
    * @param indentAmt the amount of spaces for indenting
    * @param str the string needs to be format
    * @return the format text string
    */ 
  static string
  fText(int indentAmt, const string& str);

  /**
    * Returns a string that contain blank spaces depending on the amount to
    * indent. 
    *
    * @param indentAmt the amount of spaces for indenting
    */
  static string
  indent(int indentAmt);

  /**
    * Returns a string with whitespaces removed.
    *
    * @param s the initial string with whitespaces
    */
  static string
  normalizedString (string s);

private:

  /**
    * constructor. 
    */
  Util();
  
};

} // end of name space

#endif 
