#include <sstream>
#include <iostream>
#include "StringUtil.hpp"
#include "AkentiTools.hpp"

using namespace std;

/**
  * <pre>
  * <b>akenti:</b>
  * </pre>
  */
void
printUsage() {
  cerr << "Usage:akenti tool args" << endl
       << "Server side tools:" << endl
       << "  CheckAccess             (CA)  - checks a user's access to a resource." << endl
       << "  CheckPolicy             (CP)  - collects and checks resource policy." << endl
       << "  ResourceBrowse          (RB)  - browses a resource." << endl
       << "  CreateResource          (CR)  - creates a resource." << endl
       << "  UploadPolCert           (UP)  - uploads a policy certificate." << endl
       << "  DeletePolCert           (DP)  - deletes a policy certificate." << endl
       << "Remote tools:" << endl
       << "  RemoteCheckAccess       (RCA) - checks a user's access to a remote resource." << endl
       << "  RemoteCheckPolicy       (RCP) - remotely collects and checks resource policy." << endl
       << "  RemoteResourceBrowse    (RRB) - browses a remote resource." << endl
       << "  RemoteCreateResource    (RCR) - creates a remote resource." << endl
       << "  RemoteUploadPolCert     (RUP) - remotely uploads a policy certificate." << endl
       << "  RemoteDeletePolCert     (RDP) - remotely deletes a policy certificate." << endl
       << "Akenti Certificate tools:" << endl
       << "  CertGen                 (CG)  - generates akenti certs from templates." << endl
       << "  PrintAkentiCertTemplate (PT)  - prints akenti cert template." << endl
       << "  ConvertAkentiCert       (CO)  - converts an akenti cert from and to XML/PEM." << endl
       << "  VerifyAkentiCert        (VA)  - verifies an akenti cert." << endl
       << "  PrettyPrintAkentiCert   (PP)  - pretty prints an akenti cert" << endl
       << "X509 cerificate tools:" << endl
       << "  VerifyX509Cert          (VX)  - verifies an x509 cert." << endl
       << "  HashX509                (HX)  - computes the hash of an x509 cert." << endl
       << "Other useful tools:" << endl
       << "  PrintConfigTemplate     (PC)  - prints configuration templates" << endl
       << "  FindUC                  (FU)  - collects UC certs from a directory." << endl;
}

int main(int argc, char** argv) {
  if (argc > 1) {
    bool (*cmpr)(const string&, const string&) = Akenti::StringUtil::equalsIgnoreCase;

    // SERVER SIDE
    if (cmpr("CA", argv[1]) || cmpr("CheckAccess", argv[1])) {
      return CheckAccess::main(--argc, ++argv);  
    } else if (cmpr("CP", argv[1]) || cmpr("CheckPolicy", argv[1])) {
      return CheckPolicy::main(--argc, ++argv);  
    } else if (cmpr("RB", argv[1]) || cmpr("ResourceBrowse", argv[1])) {
      return ResourceBrowse::main(--argc, ++argv);  
    } else if (cmpr("CR", argv[1]) || cmpr("CreateResource", argv[1])) {
      return CreateResource::main(--argc, ++argv);  
    } else if (cmpr("UP", argv[1]) || cmpr("UploadPolCert", argv[1])) {
      return UploadPolicyCertificate::main(--argc, ++argv);  
    } else if (cmpr("DP", argv[1]) || cmpr("DeletePolCert", argv[1])) {
      return DeletePolicyCertificate::main(--argc, ++argv);  
    } 

    // REMOTE
    if (cmpr("RCA", argv[1]) || cmpr("RemoteCheckAccess", argv[1])) {
      return RemoteCheckAccess::main(--argc, ++argv);  
    } else if (cmpr("RCP", argv[1]) || cmpr("RemoteCheckPolicy", argv[1])) {
      return RemoteCheckPolicy::main(--argc, ++argv);  
    } else if (cmpr("RRB", argv[1]) || cmpr("RemoteResourceBrowse", argv[1])) {
      return RemoteResourceBrowse::main(--argc, ++argv);  
    } else if (cmpr("RCR", argv[1]) || cmpr("RemoteCreateResource", argv[1])) {
      return RemoteCreateResource::main(--argc, ++argv);  
    } else if (cmpr("RUP", argv[1]) || cmpr("RemoteUploadPolCert", argv[1])) {
      return RemoteUploadPolicyCertificate::main(--argc, ++argv);  
    } else if (cmpr("RDP", argv[1]) || cmpr("RemoteDeletePolCert", argv[1])) {
      return RemoteDeletePolicyCertificate::main(--argc, ++argv);  
    } 

    // AKENTI CERT TOOLS
    if (cmpr("CG", argv[1]) || cmpr("CertGen", argv[1])) {
      return CertGen::main(--argc, ++argv);  
    } else if (cmpr("PT", argv[1]) || cmpr("PrintAkentiCertTemplate", argv[1])) {
      return PrintAkentiCertTemplate::main(--argc, ++argv);  
    } else if (cmpr("CO", argv[1]) || cmpr("ConvertAkentiCert", argv[1])) {
      return ConvertAkentiCert::main(--argc, ++argv);  
    } else if (cmpr("VA", argv[1]) || cmpr("VerifyAkentiCert", argv[1])) {
      return VerifyAkentiCert::main(--argc, ++argv);  
    } else if (cmpr("PP", argv[1]) || cmpr("PrettyPrintAkentiCert", argv[1])) {
      return PrettyPrintAkentiCert::main(--argc, ++argv);  
    } 

    // X509 CERT TOOLS
    if (cmpr("VX", argv[1]) || cmpr("VerifyX509Cert", argv[1])) {
      return VerifyX509Cert::main(--argc, ++argv);  
    } else if (cmpr("HX", argv[1]) || cmpr("HashX509", argv[1])) {
      return HashX509::main(--argc, ++argv);  
    } 

    // OTHER
    if (cmpr("FU", argv[1]) || cmpr("FindUC", argv[1])) {
      return FindUC::main(--argc, ++argv);  
    } else if (cmpr("PC", argv[1]) || cmpr("PrintConfigTemplate", argv[1])) {
      return PrintConfigTemplate::main(--argc, ++argv);  
    }
  }

  printUsage();
  return 2;
}
