#ifndef AKENTI_OBJECT_HPP
#define AKENTI_OBJECT_HPP

#include <string>
#include "Xerces-Decls.hpp"

using std::string;

namespace Akenti {

class AkentiInputStream;
class AkentiOutputStream;

/**
  * Defines the interface that <i>Akenti</i> elements must implement. 
  *
  * @see AkentiInputStream
  * @see AkentiOutputStream
  *
  * @version 1.1 00/05/01
  *
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  **/ 

class AkentiObject {

public:

  /**
    * Destroys this object.
    **/
  virtual ~AkentiObject() {}

  /**
    * Reads an Akenti object from an Akenti input stream. 
    *
    * @param source the akenti input stream to read from
    */
  virtual void readObject(AkentiInputStream& source) = 0;

  /**
    * Writes an Akenti object to an Akenti output stream. 
    *
    * @param drain the akenti output stream to write to
    */
  virtual void writeObject(AkentiOutputStream& drain) const = 0;

  /**
    * Populates the XML <i>element<i> from this <i>AkentiObject</i>.
    *
    */
  virtual void toXML(DOMElement* element) const = 0;

  /**
    * Initializes this <i>AkentiObject</i> from the XML <i>element</i>.
    */
  virtual void fromXML(const DOMElement* element) = 0;

  /**
    * Returns a string representation of this object for debugging  
    * purposes.
    *
    * @return debugging info
    */
  virtual string paramString() const = 0;

};

} // end of name space

#endif
