#ifndef DIRECTORY_HPP
#define DIRECTORY_HPP

#include <string>
#include "AkentiObject.hpp"

using std::string; 

namespace Akenti {

class URL;

/**
  * A <i>Directory</i> object contains a string representation of a  URL.
  * It was introduced in addition to the URL class for two reasons.
  *
  * 
  * 1) Policy and UseConditition Certificates contain urls pointing to
  *    directories in which to search for other certificates. Since
  *    these urls are contained in the signable part of a certificate,
  *    we must maintain the exact string representation of the 
  *    url. 
  *
  *    Example: "http://hostname:8080/filename 
  *             "http://hostname:80/filename/ 
  *             "http://hostname/filename/ 
  *    The URL class can parse this but the URL.toString() will
  *    not return the exact string.  Should it? 
  *
  * 2) A <i>URLHandler</i> may not be installed. And not being able
  *    to parse a particular url should not trigger an exception
  *    when reading a certificate.
  *
  * 3) A <i>Directory</i> object provides us a cleaner and a more flexible
  *    solution for the future.
  *    
  * @see AkentiObject
  * @see URL
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  **/

class Directory : public AkentiObject {

public:

  /** 
    * Default constructor.
    */
  Directory();
  
  /**
    */   
  Directory(const string& url);

  /**
    *
    */
  ~Directory();

  /**
    */
  void operator=(const Directory& dir);

  /**
    */
  const string& toString() const;

  /**
    *
    */
  bool operator==(const Directory& dir) const;

  /**
    */
  bool parseDir(URL& url) const;

  /**
    */
  void writeObject(AkentiOutputStream& drain) const;

  /**
    */
  void readObject(AkentiInputStream& source);

  /**
    * Populates the XML element <i>dir</i> from this <i>Directory</i>.
    */
  void toXML(DOMElement* dir) const;

  /**
    * Initializes this <i>Directory</i> from the XML element <i>dir</i>.
    */
  void fromXML(const DOMElement* dir);

  /**
    * Used for debugging.
    *
    * @return a string representation of this object
    *
    * @see AkentiObject
    */
  string paramString() const;

private:

  string url;

};

} // end of name space

#endif
