#ifndef AK_PROPERTIES_HPP
#define AK_PROPERTIES_HPP

#include <utility>
#include <map>
#include <vector>
#include <string>
#include <iosfwd>

using std::map;
using std::vector;
using std::string;
using std::pair;
using std::istream;

/**
  * The Properties class holds a set of named properties. The Properties can be saved
  * to a stream or loaded from a stream. Each key and its corresponding value in the
  * property list is a string. 
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

namespace Akenti {

class Properties {

public:

  /**
    * Constructs this object.
    */
  Properties();

  /**
    * Destroys this object.
    */
  ~Properties();

  /**
    * Reads a property list (key and element pairs) from a file. 
    */
  void load(const string& filename);

  /**
    * Reads a property list (key and element pairs) from an input stream. 
    */
  void load(istream& is);

  /**
    */
  string setValue(const string& key, const string& value);

  /**
    * Searches for the property with the specified key in this property list.
    * If the key is not found the method returns the <i>defaultValue</i>.
    */
  const string& getValue(const string& key, 
                         const string& defaultValue = "") const;

  /**
    */
  string setValue(const pair<string, string>& key, const string& value);

  /**
    */
  const string& getValue(const pair<string, string>& key, 
                         const string& defaultValue = "") const;

  /**
    */
  vector<string> getKeys() const;

  /**
    */
  vector< pair<string,string> > getKeyPairs() const;

  /**
    * Returns the contents of the Properties table
    */  
  string paramString() const;

  /**
    */
  static Properties& getSystemProperties();

private:

  map<string, string> pairs;

  typedef pair<string, string> Pair;

  map<Pair, string> triplets;

  static Properties props;

};

} // end namespace Akenti

#endif
