#ifndef AK_REVOKED_CERTIFICATE_IMPL_HPP
#define AK_REVOKED_CERTIFICATE_IMPL_HPP

#include <vector>
#include "UtcTime.hpp"
#include "V3Extension.hpp"

namespace Akenti {

/**
  * This abstract class provides the information about a
  * certificate which has been revoked.
  * 
  * @see UtcTime
  * @see V3Extension
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

class RevokedCertificateImpl {

public:

  /**
    * Delects this object.
    */
  virtual ~RevokedCertificateImpl() {
  }

  /**
    * Returns the serialNumber of this certificate,
    * together with the issuing CA(certificate authority)'s
    * name to uniquely identify this certificate
    */  
  virtual long getCertificateNumber() const = 0;

  /**
    * Returns <i>UtcTime</i> the certificate was revoked.
    */
  virtual UtcTime getRevocationDate() const = 0; 

  /**
    * Return <i>vector</i> holding the extension's information.
    */ 
  virtual std::vector<V3Extension> getExtensions() const = 0;
   
  /**
    * Returns a string representation for RevokedCertificateImpl 
    * which is used for debugging purposes.
    *
    * @return debugging info
    */
  virtual string paramString() const = 0;

 
};

} // end of namespace Akenti

#endif
